==================
analyse_wb_senegal
==================


.. image:: https://img.shields.io/pypi/v/analyse_wb_senegal.svg
        :target: https://pypi.python.org/pypi/analyse_wb_senegal

.. image:: https://img.shields.io/travis/dienglord/analyse_wb_senegal.svg
        :target: https://travis-ci.com/dienglord/analyse_wb_senegal

.. image:: https://readthedocs.org/projects/analyse-wb-senegal/badge/?version=latest
        :target: https://analyse-wb-senegal.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Analyse de donnees economiques du Senegal avec l'API World Bank


* Free software: MIT license
* Documentation: https://analyse-wb-senegal.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
